package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*```````````0```````
M`+&8``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*IP````````JG``
M```````0``````$````&````````JZ@```````"[J````````+NH````````
M!.`````````%"````````!```````@````8```````"KN````````+NX````
M````N[@````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````HU````````"C4````````*-0`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*NH````````NZ@`````
M``"[J`````````18````````!%@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````0````#``````````0````4`````T=.
M50#.EZH&5'%".32WOHUD27X/&2W3W@``````````````0P````````!=````
M``````````````````````````!7````````````````````+P`````````P
M````````````````````4````````````````````"H`````````5```````
M```[`````````"@`````````5@````````!"`````````#$`````````/```
M````````````````````````````.```````````````````````````````
M-P`````````7`````````$X`````````*P`````````R`````````!8`````
M````40````````!/````````````````````````````````````````````
M````````*0`````````=`````````"4```````````````````!-````````
M`$P````````````````````_````````````````````/@````````!:````
M````````````````(P`````````$````````````````````20``````````
M``````````8```````````````````!9`````````#H`````````&0``````
M``!!````````````````````2`````````!5`````````!@`````````-@``
M```````+`````````$,`````````/0`````````M`````````$4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````H``````````@``````````````````
M``4`````````2P```````````````````$8`````````$@````````!;````
M````````````````````````````````````````````````"```````````
M``````````X`````````4@`````````,``````````<`````````&P``````
M```3````````````````````#0```````````````````"0`````````````
M`````````````````%,`````````)@````````````````````D`````````
M```````````@`````````````````````````````````````````!X`````
M```````````````G``````````\`````````-0````````!*````````````
M````````,P`````````B`````````!0`````````$0`````````N````````
M`!P`````````'P````````!$````````````````````````````````````
M`````"P`````````7```````````````````````````````(0``````````
M````````````````````6``````````0````````````````````%0``````
M`````````````#D`````````0````````````````````$<`````````&@``
M```````T````````````````````````````````````````````````````
M``````````````````````,````1````0P````0````(A`1`!0`0$""$`(:`
M!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)````2@```%(`
M``!3````5`````````!6````5P```%@```!9````6@```%P``````````!_?
MQ6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C2ZR'U_I"+#_E
MPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,%0N7.@V;G*E_
M"@*GX%">&FM)^^"C```````````````````````````````````````````#
M```,````````'F```````````````V\2````````````````````````````
M`I\2`````````````````````````````,P1````````````````````````
M`````<,2`````````````````````````````@82````````````````````
M`````````H82`````````````````````````````2@2````````````````
M`````````````D(2``````````````````````````````$@````````````
M`````````````````G\2`````````````````````````````&<2````````
M`````````````````````;82`````````````````````````````3$2````
M`````````````````````````M$2`````````````````````````````842
M`````````````````````````````?82````````````````````````````
M`*82`````````````````````````````6H2````````````````````````
M`````-02`````````````````````````````!`@````````````````````
M`````````K<2`````````````````````````````(H2````````````````
M`````````````,H1`````````````````````````````+02````````````
M`````````````````"P@`````````````````````````````/,2````````
M`````````````````````JD2`````````````````````````````.H2````
M`````````````````````````),6`````````````````````````````3<2
M`````````````````````````````7X2````````````````````````````
M`E42`````````````````````````````5(2````````````````````````
M`````L(2`````````````````````````````0D2````````````````````
M`````````%@B`````````````````````````````=`2````````````````
M`````````````;$2`````````````````````````````+L2````````````
M`````````````````<H2`````````````````````````````6,2````````
M`````````````````````:(2`````````````````````````````I$2````
M`````````````````````````B<2`````````````````````````````'D2
M`````````````````````````````7<2````````````````````````````
M`>$2`````````````````````````````/(2````````````````````````
M`````2$2`````````````````````````````A(2````````````````````
M`````````;X2`````````````````````````````G,2````````````````
M`````````````J02`````````````````````````````>\2````````````
M`````````````````F81`````````````````````````````8P2````````
M`````````````````````/H2`````````````````````````````1,2````
M`````````````````````````4<2`````````````````````````````-P2
M`````````````````````````````0$2````````````````````````````
M`C,2`````````````````````````````$82````````````````````````
M`````902`````````````````````````````9L1````````````````````
M`````````W@2```.````````7D@`````````U@```\T2```.````````51``
M```````&_@```%,2```.````````)8`````````"@````N\2```.````````
M1W``````````!@```PT2```.````````7!`````````",@```_,2```.````
M````1W@````````"7````[,0```8````````P(@``````````````P`2```.
M````````2=@`````````-@```R,2```.````````4/@`````````@````X01
M```0````````8L``````````!````Z`2```.````````7Y`````````!Z@``
M`ZL2```.````````1D``````````.````\@0```8````````P+``````````
M`````^$2```.````````5!@`````````]```!`H2```.````````47@`````
M````>````Y,0```7````````P````````````````T<2```.````````2A``
M```````!5````]H0```8````````P(@`````````````!``1```7````````
MP(``````````"````YD2```.````````*````````````````[\2```.````
M````7R``````````;````Y4@```7````````P````````````````UT2```.
M````````4^@`````````+````S$2```.````````1G@`````````^````U,2
M```.````````88``````````_```!!(2```.````````2V@````````%C`!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL
M`')E861L:6YK`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7W-V7W-E='!V`&UE
M;6-H<@!097)L7W-V7W-E='!V;@!?7V5N=FER;VX`<W1R;F-M<`!?7VUE;6UO
M=F5?8VAK`')E86QL;V,`;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`8F]O=%]$
M>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!G971P:60`
M7U]M96UC<'E?8VAK`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M
M8W!Y`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G
M971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P
M96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F
M<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P
M97)L7W)U;@!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`+W5S<B]L
M:6(O<&5R;#4O-2XT,BXP+W,S.3!X+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%
M``````````(``0`"``(``0`!``(``0`!``(``P`"``(``0`"``$``0`$``(`
M`0`!``(``@`"``$`!0`!``(``0`!``(``0`!``$``@`"``(``@`!``(``@`&
M``$``0`&``(`!@`%``(``0`"``$``@`"``$``@`"``8``0`$``(``0`'``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`&```"Y0```!``````!I:1M`````<```0?````$`UI:10`
M```&```$*@```!`&EI&S````!0``!#0````0"6D9=`````0```0_````$`EI
M&7(````#```$2P```!`-:6D2`````@``!%<`````````````NZ@`````````
M#````````"D`````````N[``````````#````````"BX````````O_@`````
M````#````````"6`````````P`@`````````#````````,`(````````P"``
M````````#````````*,P````````P"@`````````#````````&,<````````
MP#@`````````#````````&.\````````P$``````````#````````&/`````
M````P$@`````````#````````*,D````````P%``````````#````````&,B
M````````P%@`````````#````````*,L````````P&@`````````#```````
M`*,4````````P'``````````#````````*,:````````P(``````````#```
M`````&6D````````OZ`````$````"@``````````````````OZ@````)````
M"@``````````````````O[`````*````"@``````````````````O[@````5
M````"@``````````````````O\`````:````"@``````````````````O\@`
M```>````.```````````````````O]`````?````"@``````````````````
MO]@````A````"@``````````````````O^`````E````"@``````````````
M````O^@````X````"@``````````````````O_````!"````"@``````````
M````````O?`````"````"P``````````````````O?@````#````"P``````
M````````````O@`````%````"P``````````````````O@@````&````"P``
M````````````````OA`````'````"P``````````````````OA@````(````
M"P``````````````````OB`````+````"P``````````````````OB@````,
M````"P``````````````````OC`````-````"P``````````````````OC@`
M```.````"P``````````````````OD`````/````"P``````````````````
MOD@````0````"P``````````````````OE`````1````"P``````````````
M````OE@````2````"P``````````````````OF`````3````"P``````````
M````````OF@````4````"P``````````````````OG`````6````"P``````
M````````````OG@````7````"P``````````````````OH`````9````"P``
M````````````````OH@````;````"P``````````````````OI`````<````
M"P``````````````````OI@````=````"P``````````````````OJ`````@
M````"P``````````````````OJ@````B````"P``````````````````OK``
M```C````"P``````````````````OK@````D````"P``````````````````
MOL`````E````"P``````````````````OL@````F````"P``````````````
M````OM`````G````"P``````````````````OM@````H````"P``````````
M````````ON`````I````"P``````````````````ON@````J````"P``````
M````````````OO`````K````"P``````````````````OO@````L````"P``
M````````````````OP`````M````"P``````````````````OP@````N````
M"P``````````````````OQ`````O````"P``````````````````OQ@````P
M````"P``````````````````OR`````Q````"P``````````````````OR@`
M```R````"P``````````````````OS`````S````"P``````````````````
MOS@````T````"P``````````````````OT`````U````"P``````````````
M````OT@````V````"P``````````````````OU`````W````"P``````````
M````````OU@````Y````"P``````````````````OV`````Z````"P``````
M````````````OV@````[````"P``````````````````OW`````\````"P``
M````````````````OW@````]````"P``````````````````OX`````^````
M"P``````````````````OX@````_````"P``````````````````OY````!`
M````"P``````````````````OY@```!!````"P``````````ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```3[+`$```4)OC$!````2Y`@`1IX0``PWAXT#Q$``$
MZV_PT``$!_0``.,0\#@`),`0``!/F=('\#`0".,0$!``!`?Q!P`'``<`P!``
M`$^8XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```3XSC$!````0'\0T0
MXQ`0#``4P/3____5````&,`0``!/@.,0$```!`?Q#1#C$!`,`!3`]/___\4`
M```PP!```$]TXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```3VCC$!``
M``0'\0T0XQ`0#``4P/3___^E````8,`0``!/7.,0$```!`?Q#1#C$!`,`!3`
M]/___Y4```!XP!```$]0XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```
M3T3C$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!/..,0$```!`?Q#1#C
M$!`,`!3`]/___V4```#`P!```$\LXQ`0```$!_$-$.,0$`P`%,#T____50``
M`-C`$```3R#C$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!/%.,0$```
M!`?Q#1#C$!`,`!3`]/___S4```$(P!```$\(XQ`0```$!_$-$.,0$`P`%,#T
M____)0```2#`$```3OSC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!.
M\.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```$[DXQ`0```$!_$-$.,0
M$`P`%,#T___^]0```6C`$```3MCC$!````0'\0T0XQ`0#``4P/3___[E```!
M@,`0``!.S.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```$[`XQ`0```$
M!_$-$.,0$`P`%,#T___^Q0```;#`$```3K3C$!````0'\0T0XQ`0#``4P/3_
M__ZU```!R,`0``!.J.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```$Z<
MXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```3I#C$!````0'\0T0XQ`0
M#``4P/3___Z%```"$,`0``!.A.,0$```!`?Q#1#C$!`,`!3`]/___G4```(H
MP!```$YXXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```3FSC$!````0'
M\0T0XQ`0#``4P/3___Y5```"6,`0``!.8.,0$```!`?Q#1#C$!`,`!3`]/__
M_D4```)PP!```$Y4XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```3DCC
M$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!./.,0$```!`?Q#1#C$!`,
M`!3`]/___A4```*XP!```$XPXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`
M$```3B3C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!.&.,0$```!`?Q
M#1#C$!`,`!3`]/___>4```,`P!```$X,XQ`0```$!_$-$.,0$`P`%,#T___]
MU0```QC`$```3@#C$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!-].,0
M$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```$WHXQ`0```$!_$-$.,0$`P`
M%,#T___]I0```V#`$```3=SC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0
M``!-T.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```$W$XQ`0```$!_$-
M$.,0$`P`%,#T___]=0```ZC`$```3;CC$!````0'\0T0XQ`0#``4P/3___UE
M```#P,`0``!-K.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```$V@XQ`0
M```$!_$-$.,0$`P`%,#T___]10```_#`$```393C$!````0'\0T0XQ`0#``4
MP/3___TU```$",`0``!-B.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!``
M`$U\XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```37#C$!````0'\0T0
MXQ`0#``4P/3___T%```$4,`0``!-9.,0$```!`?Q#1#C$!`,`!3`]/___/4`
M``1HP!```$U8XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```34SC$!``
M``0'\0T0XQ`0#``4P/3___S5```$F,`0``!-0.,0$```!`?Q#1#C$!`,`!3`
M]/___,4```2PP!```$TTXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```
M32CC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!-'.,0$```!`?Q#1#C
M$!`,`!3`]/___)4```3XZV_P,``DX_#_./]QXS#PJ``DXT#PH``D4"#PM$%`
M\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`HP.7___^RQ$@``$SSQ"@`
M`$T(N00`-,#E```>5\08``!-")4`$`"GA`"VP#```$SQXU`P```$6.#PM.-E
ML```!%@`\+2G"@`$E@-DBKD4`*#L;@`#`-CK*@`#``W`Y?___O3C$/"H``3`
M0```'[SC,!````3C0"`(`"3C,"```"3$6```32+C4"`0`"3`````'ZSC`"`8
M`"3$*P``32)8X/"T[.P`Q0%^[%X``P#8[`[__P#804`0"*<X``2G`0`!IW0`
M@H@```&Y%`"CZUH``P`-XZ!````$XZ4@```D[!,``0#8XU!`"``$N10`$>L1
M``,`#>-1(```)*<Z``*G2P`0IP;_X^RN``,`V+D$`%*Y%`#JZSX``P`-02,@
M`+D4`$;E2"````"G:0``P#````]PQ"@``$S=P.7___PF["@`4@!^Q"@``$S4
MP.7___WM03#PO+D$`&+`(```'BW`Y0``#*OL*`!'`'S$*```3,'`Y?__^]K`
MY?___0?5!_#`L"BG=`!9N00`)NMO\/@`!`?^P.7___RYQ"L``$RJ["@`3@!\
MP.7___TPP#```$PQXR`P```$XT*P```$D@!)!J?T_SCC,$````3C,"`@`"1!
M0!`0IS@`!>PU_W9@=J?T_Y3$*```3(7`Y?___"ZG]/^KP$```$QYXR!````"
MIX0`!\#E```;1:?T_[%!,/"\P"```!VIP.4```Q/Q"L``$QD["C_I`!\I_3_
M[:>H``2G]/]NP.7___V8IRD``<#E___](T%`\`CC,/````2G"?_PN8``\*?[
M_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```2^7C("````3`Y?___H,`
M``<'!P<'!\`0``!,(,`@``!,'>P2``J`9,08``!+K^P8``0`?`?Q!_X'!P<'
M!P?`$```3`S`(```3`FY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`"NPX``T`
M?,08``!+DNP8``<`?,`@``!+\`?Q!_X'!P<'!P?KO_!8`"3`L```2^7C\/]@
M_W&5`+``IW0`%<`0``!+A^,0$````J>$``C$*```2Y/`Y?___(S`Y?___ZV2
M`;``Z[_P^``$!_[`]/___[@'!^MO\#``)+)/``#C\/S0_W'K```@``VR3P`!
MN00`$-('\R@0*$%@\*A!4"`XI[D`!.-`4```!.,P4`@`!.ND`"``#..@8```
M).MS`"``#.-P8!``),!*`````.-`8`@`),`Z`````.,P8!@`)$%04!"G:P`@
MI[?_WFA0\1"SS0`5XZ#Q&``$X]#Q(``$XW#PJ``$XV#PL``$N00`@KD$`)JY
M!`!=04#PN*>Y`$"SP0!VN00`)[/!``7CX$````2Y!``^XS!`,`""N8(`,KF"
M`!/L42"_(57L42`^`5;C4$!P`"2Y!``9L\T`)[/-`)"G2P`(I[<*L;D$`.BS
MS0"%PFI:@GF9XS#@```$PHI:@GF9XT#@$``$X[#@&``$XU#@"``$XU#PH``D
MN>BPEK/!`"C"JEJ">9FYY["$[&,@OR55ZR4``@`,[&,@.@56["4`(1Y6N>10
M6+F"`%NSP0`:PGI:@GF9[*(@OP!5XW#@(``(N>>@%+D(`':Y@``3N0@`=;F"
M`!3LAR"_`%6Y"``9['<[OR55ZY,``@`,['@`.@56[),`(1Y6XV#PN``$N8(`
M*<)J6H)YF;F``"BYZ$!6N8(`*KD(`"6Y"``7XV#PP``$['$@OP!5PFI:@GF9
M[!$[OR55N0@`:NP7`#H%5NRI(+\`5;D(`!+K*``"``SL*``A'E;L@2"_`%6Y
MYR!9[)$[OR55[)@`.@56N>1P%>-0\,@`!+F"`!K"6EJ">9FY"``6N0@`6KD(
M`!GLHB"_`%7L83N_)57KEP`"``SLEP`A'E;L<2"_`%6Y@@`I[&<`.@56N>2`
M$N,@\-``!+F"`!K"*EJ">9FY"``5N0@`*KD(`!;LJ2"_`%7K:``"``SL:``A
M'E;L@2"_`%6YYV!9[)$[OR55[)@`.@56N>1P%>-0\-@`!+F"`!K"6EJ">9FY
M"``2N0@`6KD(`!GLIB"_`%7KEP`"``SLEP`A'E;L<2"_`%6YYY`F[&$[OR55
M[&<`.@56N>2`$N,@\.``!+F"`!K"*EJ">9FY"``5N0@`*KD(`!;LJ2"_`%7K
M:``"``SL:``A'E;L@2"_`%6YYV!9[)$[OR55[)@`.@56N>1P%>-0\.@`!+F"
M`!K"6EJ">9FY"``2N0@`6KD(`!GKIP`"``SLEB"_`%7LIP`A'E;L<2"_`%6Y
MYZ`F[&$[OR55[&<`.@56N>2`$N,@\/``!+F"`!G"*EJ">9FY"``5N0@`*;D(
M`!;L:B"_`%7KF``"``SC4/#X``3LF``A'E;"6EJ">9GL@2"_`%6Y"`!6N8(`
MJ>P1.[\E5;F``*?L&``Z!5:Y@@"F[&D@OP!5N0@`HNLG``(`#+D(`*'L)P`A
M'E;L>B"_`%7LJCN_)57LIP`Z!5:Y@@"2XQ#Q```$N8``F,(:6H)YF;F"`):Y
M"``6N0@`E>QB(+\`5;D(`)KC4/$(``3KJ``"``S"6EJ">9GLJ``A'E:Y@@`J
MN8``)[F"`":Y"``A[(D@OP!5[)D[OR55[)@`.@56N0@`DKGH8"6SP0!BL\T`
M5NQJ(+\`5>L7``(`#.P7`"$>5KF"`*&Y@`"HN8(`IKD(`*7L*2"_`%6SS0!R
M[)D[OR55[)(`.@56N0@`FK/-`*&Y"`!VZV@``@`,[&@`(1Y6[($@OP!5N0@`
MJ+/!`">SP0`:['D[OR55[*D@OP!5L\T`4;/-`)+L>@`Z!5:Y@@`6N8``$KF"
M`!BY"``9ZY(``@`,[)(`(1Y6["8@OP!5N8(`:;F``&JY@@!BN0@`9;D(`!?"
MVEJ">9GL<2"_`%6Y"`#2[!$[OR55ZXH``@`,[!<`.@56[(H`(1Y6N0@`%NRI
M(+\`5;GG@&FYY'`F[)$@OP!5[&@@OP!5[%$[OR55N>>@$NQ9`#H%5KD(`!WC
MT/$H``2Y"``5PMI:@GF9N>B@+>NG``(`#.RG`"$>5KF"`(KL<2"_`%7L43N_
M)56YY)`8N00`A>R'`#H%5KF"`!;CT/$P``2Y"``2PMI:@GF9N0@`&+GH8"WK
MB0`"``SL:B"_`%7LB0`A'E:Y@@"H[)$@OP!5[%$[OR55X]#Q.``$N>1P&L+:
M6H)YF;D$`*7LJ0`Z!5:Y@@`6N0@`$KGH8"VY"``:[&@@OP!5[-$[OR55ZZ<`
M`@`,[-$@.@56[*<`(1Y6N>>@>..`\4``!,**6H)YF<`:`````+GH8%BY@`!Y
MN8(`=NQJ(+\`5;D(`'+K*0`"``RY"`!]["D`(1Y6[)<[OR55N><@VNR7(#H%
M5KF``-&Y@@#6N0@`U;D(`-GLC3N_)57LC2`Z!5;K40`"``RSP0!([%$`(1Y6
MXX#Q4``$N>=0$L**;MGKH;D:`(*SS0`DN8(`%^.@\4@`!,*J;MGKH;D(`*;L
M9R*_/E6Y&@"A[&<"(1Y6N0@`HKGG8!7LFCN_)56Y@@`=[)H@.@56['TBOSY5
MN1H`@>Q]`B$>5KD(`(GC(/%8``3"*F[9ZZ&YYW"6N1H`);GGH%GL&#N_)56Y
M&@`E[!@@.@56N0@`(>Q2.[\E5>Q2(#H%5N.0\6``!,*:;MGKH;D:`);L:B*_
M/E7L:@(A'E:YYV#7N8(`V+D:`)VY"`"5[%D[OR55[%D@.@56XZ#Q:``$PJIN
MV>NAN1H`I^QX(K\^5>QX`B$>5KGG<!:Y@@`2N1H`H;D(`*7L6CN_)57L6B`Z
M!5;C@/%P``3"BF[9ZZ&Y&@"&[&(BOSY5[&("(1Y6N>=@)[F"`"FY&@""N0@`
MA>Q8.[\E5>Q8(#H%5N,0\7@`!,(:;MGKH;D:`!?L>2*_/E7L>0(A'E:YYW#6
MN8(`VKD:`!VY"``5[%$[OR55[%$@.@56XY#Q@``$PIINV>NAN1H`ENQJ(K\^
M5>QJ`B$>5KGG8">Y@@`HN1H`DKD(`)7L63N_)57L62`Z!5;CH/&(``3"JF[9
MZZ&Y&@"G['@BOSY5['@"(1Y6N>=PUKF"`-&Y&@"MN0@`I>Q:.[\E5>Q:(#H%
M5N.`\9``!,**;MGKH;D:`(;L82*_/E7L80(A'E:YYV`GN8(`*;D:`(*Y"`"%
M[%@[OR55[%@@.@56XQ#QF``$PAINV>NAN1H`%^QY(K\^5>QY`B$>5KGG<-:Y
M@@#:N1H`';D(`!7L43N_)57L42`Z!5;CD/&@``3"FF[9ZZ&Y&@"6[&HBOSY5
M[&H"(1Y6N>=@)[F"`"BY&@"2N0@`E>Q9.[\E5>Q9(#H%5N.@\:@`!,*J;MGK
MH;D:`*?L>"*_/E7L>`(A'E:YYW#6N8(`T;D:`*VY"`"E[%H[OR55[%H@.@56
MXX#QL``$PHINV>NAN1H`ANQA(K\^5>QA`B$>5KGG8">Y@@`IN1H`@KD(`(7L
M6#N_)57L6"`Z!5;C$/&X``3"&F[9ZZ&Y&@`7['DBOSY5['D"(1Y6N>=PUKF"
M`-JY&@`=N0@`%>Q1.[\E5>Q1(#H%5N.0\<``!,*:;MGKH;D:`);L:B*_/E7L
M:@(A'E;CH/'(``2YYV`GPJINV>NAN8(`*+D:`*>Y&@"2['@BOSY5N0@`E>QX
M`B$>5NQ9.[\E5;GG<-;L62`Z!5:Y@@#1XX#QT``$N1H`K<**;MGKH;D(`*6Y
M&@"&[%H[OR55[&$BOSY5[%H@.@56[&$"(1Y6[-DBOSY5N>=@)^S9`B$>5KF"
M`"FYY]"6N8(`FKD:`(+C$/'8``2Y"`"%["HBOSY5[%@[OR55["H"(1Y6PAIN
MV>NAXZ#QX``$N1H`%\*J;MGKH>QX(+\`5;D:`!GL5P`Z!5:YYR"=N0@`%;F"
M`(FY&@"F[&$@OP!5[!$[OR55[!8`.@56N1H`J..`\>@`!+D(`*'"BH\;O-SK
M%P`"``RY&@"-[!<`(1Y6[-$@OP!5N>304K/!`%CL>CN_)57LBB"_`%6YYA"B
MN8``IKF!`*6SS0!5XY#Q\``$PIJ/&[S<['@`.@56N0@`I;D$`%GCD/'X``2Y
M&@!2PIJ/&[S<ZR8``@`,["8`(1Y6N>308KF!`!*YZ-#9N8``&+F!`!:Y"``5
MN0@`I[/!`&WL>B"_`%7LJCN_)57LIP`Z!5:Y"`"AZQ@``@`,[!@`(1Y6[-$@
MOP!5N>304NQJ(+\`5>R*.[\E5;GF$**Y@`"GN8$`I;/-`%;LA@`Z!5;CD/(`
M``2Y"`"EPIJ/&[S<N0@`J+D$`%FY&@!2ZR<``@`,["<`(1Y6N>30<KF!`!*Y
M@``6N8$`%[D(`!7LFB"_`%7LBCN_)57CH/((``3LB0`Z!5;"JH\;O-RY"`"!
MN>C0VNL6``(`#.P6`"$>5NQA(+\`5;GD8%*SP0`MN>80TKF``-FY@0#5L\T`
M4NQX(+\`5>.@\A``!+D(`-7"JH\;O-SLB#N_)56Y!`!:[(<`.@56N1H`4NLI
M``(`#.PI`"$>5KGD8)*Y"`#8N8$`$NR-(+\`5;F``!?LW3N_)56Y@0`9[-@`
M.@56N0@`%;D(`-'LG2"_`%7K%P`"``SL%P`A'E;C</(8``3">H\;O-RYZ&!G
ML\$`-NQA(+\`5;GD8%*YYA"BXW#R(``$N8``J,)ZCQN\W+F!`*6Y&@!RL\T`
M([/!`'>SS0!7[-T[OR55[-D`.@56N0@`HNMX``(`#+D(`*WL>``A'E:YY&#7
MN8$`%[F``!FY@0`=N0@`%>R*(+\`5>PJ.[\E5>.@\B@`!.PH`#H%5L*JCQN\
MW+D(`"&YZ&`:L\$`8>L9``(`#.P9`"$>5NR1(+\`5;GDD%>YYA#7N8``V+F!
M`-6SS0!6[&(@OP!5XZ#R,``$N0@`U<*JCQN\W.PB.[\E5;D$`%KL)@`Z!5:Y
M&@!7ZW@``@`,['@`(1Y6N>9P@;GDD!>Y"`#2N8``ANPM(+\`5;F!`('LW3N_
M)56Y"`"%[-(`.@56ZQ8``@`,[!8`(1Y6[&$@OP!5N>1@5[D(`(WCH/(X``2Y
MYA#7PJJ/&[S<N8``TKD(`*FY@0#5L\$`*K/-`%+LF""_`%7CH/)```2Y"`#5
MPJJ/&[S<[(@[OR55[(D`.@56N0@`V+D$`%KLC2"_`%6Y&@!7XZ#R2``$ZW(`
M`@`,PJJ/&[S<['(`(1Y6["T[OR55N8$`%[GD8->Y@``9N>A@:KF!`!VY"``5
M["@`.@56L\$`-KGH(%'K&0`"``SL&0`A'E;LT2"_`%6YY-!GN>80E[F``)BY
M@0"6L\T`8^PE(+\`5>RE.[\E5;D(`);LH@`Z!5;C4/)0``3"6H\;O-RY&@!7
MN>B@>>N8``(`#.R8`"$>5KGFD(&YY-`9[&<@OP!5[*<[OR55N8``@NRF`#H%
M5KF!`('C</)8``2Y"`"%PGJ/&[S<ZQ(``@`,N0@`?>P2`"$>5NS1(+\`5;GD
MT%FY"`"*L\$`5[GF$*FY@`"FN8$`I;/-`%7L>""_`%7L*#N_)56Y"`"E["<`
M.@56XX#R8``$PHJ/&[S<N00`6+D:`%GKE@`"``SLE@`A'E:YY-!IN8$`&;F`
M`!>Y@0`6N0@`%;D(`*+C@/)H``3L*B"_`%7"BH\;O-SLJCN_)57LH@`Z!5:Y
M"`"AZQ<``@`,[!<`(1Y6['$@OP!5N>1P6>QJ(+\`5;GHT-CLBCN_)56SP0!M
MN>80J;F``**Y@0"EL\T`5NR&`#H%5N/0\G``!+D(`*7"VH\;O-RY"`"HN00`
M7;D:`%GLVB"_`%7KD@`"``SLD@`A'E;L*CN_)56YY'")N8$`&>PM`#H%5KF`
M`!;CH/)X``2Y@0`8PJJ/&[S<N0@`%;GH<%JY"``A['([OR55['(@.@56ZQ8`
M`@`,L\$`%^P6`"$>5N-P\H``!.R!(+\`5;GF$*FYY(!IPGJ/&[S<N1H`>;/-
M`)&Y@`"MN8$`IKD(`*6YZ)":[%D[OR55[%D@.@56L\$`)^M]``(`#.Q]`"$>
M5KD$`-6SS0!2XV#RB``$PFK*8L'6N>2`I[GH@(:SP0`XL\T`8\`J`````+F!
M`!?K@@`"``RY@``2[((`(1Y6N8$`&N.@\I``!+D(`!7"JLIBP=:Y"``=N1H`
MI[GG@->SP0!*N8(`V>QY(K\^5>QY`B$>5K/-`)2Y&@!MN>=PJ.PA.[\E5;F"
M`*'L(2`Z!5:Y"``F[%([OR55[%(@.@56N1H`FNQA(K\^5;D(`)7L80(A'E;C
MT/*8``2YYV"GPMK*8L'6N8(`HKD:`-BY!`!=N1H`6NP9.[\E5>P9(#H%5KD(
M`!7L43N_)57L42`Z!5;C@/*@``3"BLIBP=:Y&@"'['(BOSY5['("(1Y6N>=P
M)KF"`"FY&@""N0@`A>Q8.[\E5>Q8(#H%5N.@\J@`!,*JRF+!UKD:`*;L:2*_
M/E7L:0(A'E:YYV#7N8(`T;D:`*VY"`"E[%H[OR55[%H@.@56XY#RL``$X]#R
MP``$PIK*8L'6PMK*8L'6N1H`E^QQ(K\^5>QQ`B$>5N,0\K@`!+GG<":Y&@#7
MN8(`*,(:RF+!UKD:`)*Y&@`6N0@`E>QH(K\^5>Q9.[\E5>QH`B$>5NQ9(#H%
M5KGG8(?L>B*_/E6Y@@"*['H"(1Y6N1H`&+GG<":Y"``5N8(`*>Q1.[\E5>.@
M\L@`!.Q1(#H%5L*JRF+!UKD:`*:Y!`!M[-DBOSY5N1H`8KD(`&7LV0(A'E:Y
MY]"7[(8[OR55N8(`D>R&(#H%5KD:`*FY"`"H[%H[OR55[%H@.@56XR#RT``$
MPBK*8L'6N1H`)^QQ(K\^5>QQ`B$>5KGG<)VY@@"6N1H`*;D(`"7L4CN_)57L
M4B`Z!5;C$/+8``3"&LIBP=:Y&@`=[-8BOSY5[-8"(1Y6N>?09[F"`&JY&@`6
MN0@`%>Q1.[\E5>Q1(#H%5N.0\N``!,*:RF+!UKD:`)?L>B*_/E7L>@(A'E:Y
MYW"-N8(`@KD:`)BY"`"5[%D[OR55[%D@.@56[&(BOSY5XZ#RZ``$[&("(1Y6
MPJK*8L'6N>=@)[D:`*VY@@`AN1H`HKD(`*7L6CN_)57L6B`Z!5;C@/+P``3"
MBLIBP=:Y&@"'['$BOSY5['$"(1Y6XQ#R^``$N>=PUL(:RF+!UKF"`-FY&@`6
MN1H`C>QI(K\^5;D(`(7L:0(A'E;L6#N_)57L6"`Z!5:YYV`GXY#S```$N8(`
M*L*:RF+!UKD:`!*Y&@"7N0@`%>QZ(K\^5>Q1.[\E5>QZ`B$>5NQ1(#H%5KGG
M<-;CH/,(``2Y@@#8PJK*8L'6N1H`INQH(K\^5>QH`B$>5KGG8(>Y@@"!N1H`
MG;D:`*BY"`"5[($BOSY5[%D[OR55[($"(1Y6[%D@.@56XR#S$``$PBK*8L'6
MN1H`)[GG@':Y@@!YN1H`)[D(`*7L>2*_/E7L6CN_)57L>0(A'E;L6B`Z!5:Y
M!`#7XQ#S&``$X]#@(``(PAK*8L'6P-H`````X]#@(``DN1H`%KGH4&*YYW`H
M[)8@OP!5N>>@TNQ6.[\E5;D:`!WL60`Z!5;L*B*_/E6Y"``5["H"(1Y6XZ#S
M(``$PJK*8L'6N0@`.KD:`#BYYR#7[($[OR55N>BP<NM9``(`#+GG8+W`>@``
M``#C<.`8`"3L82"_`%7L60`A'E:Y!``3[(8`.@56N1H`&[D(`%2Y"``8P%H`
M````XU#@$``DP!H`````XQ#@```DXS#PH``$N0@`-L`Z`````.,PX`@`)+D$
M`.#5!_,HX"BG=``*ZV_S8``$!_ZSP0!^I_3U+L#E___QW@<'!P<'!^M_\#@`
M)./P\`#_<>,`__@`(./P_UC_<>,`\*``(.,0\*`!<;D$`'.Y!`""LD\`L$$P
M\*#KNP`@``VG20__LD\`L=('$`"P*,`@```1AL#E___PD>PL`!$`?AA"IRK_
M_[D4`#)!4_"@E0!0`*=T`"+L)@`?`'[`(```/_'CX"````2Y!`!'N00`..,N
ML```!,#E___P,.,0\*`!<=4'$`"P**=T`"GK?_#@`00'_AA"N10`E$$@\*"Y
M!`!)ISD`+\#E___P:.PH_]@`?+D$`#C`<```/\2Y!`!9XX!P```$04#PH.,H
ML```!,#E___Q`Z?T_]/`Y?__\5X'!P<'!P?K;_`P`"3$&```/Y7C\/]@_W'C
M<!````*GA`!3XP`@``"4N00`DI4`(`"GA`!.[`@`##U^09"0`>,`D```E)4`
MD`"G=/_V&Y+CH'````*GA``CN00`8[D$`(*Y%`"9N00`M[D$`$FY!``XN00`
M*L#E___OX>PF``D`?D$IH`"5/2``IX0`#T&PL`CCH+````*G=/_IN00`*NMO
M\-``!`?^0:F@`;GI<#NY!``JZT,``P`*4$!@`.MO\-``!`?^IZD``*?T_^FG
MF```I_3_OP<'ZV_P,``DX_#_0/]QLD\`8.MF`"``#;)/`&&5/3``T@?PN&`H
M0:`P`;GB<*.G"```N00`&J>)``"Y!`"RLEX`@:<4__Y!,/"TN>F@F..0\*``
M),#E____;^PH`)0`?*<(``"GB0``N00`<K)>`(>G%/_^N0D`@NR8`'?`9>,`
M\+0`%,2(```^[^MP``,`#>-0L```E+D$`#N5`+``IW0`#:?T`.-!,#`!XU`P
M``"4E0`P`*>$``7L5O_W/7ZY"0`[N10`T^/@\*``!+D$`)=!+M`"XY"````(
MP.7__^ZTXR"0```D["@`-P!\XR"````$XQ"P``"0XW<@```$0A!P`!B![!@`
M&@!\04"P`:?T``_C`$```)!"`'`!04!``4%P<`$8@.P(``D`?$*`\*"5/?"@
MIW3_[Y(]<`"GN0``XSN@``"00CMP`:>[``'L-O_Y`'S5!_"X8"BG=`"2ZV_P
M\``$!_ZG60``X]6@``"00M4@`*=;``'LUO_Y`'RG]/_KQ(@``#YPXW"````$
MXQ!P```"IX0`;KD$`$>GF```&"FGF@`!04!`".,P0````J=T__BG*@`#N10`
M`NLP``,`#>,P\*@`),!0```^Q>,04```$J=T`#/`T```/KWC(/"H``3E3-``
M``'`Y?__[BRY!`#2["C_L`!\N10`Z;D$`#?C4/"H``3K?@`#``VY!`!'P.7_
M__#(X]"````DIYH``;D4`)GK*0`#``U!0M``Y4A`````I_3_+>,P\*@`!+D$
M`"?`Y?__[N_C((```"2Y!`#2["C_@`!\N10`&>MQ``,`#:?T_]VGV0``I_3_
M+>5(\*@`$*>8``"G]/^GP.7__^^R!P<'!P<'ZZ_P4``DX_#^R/]QLD\`L+D$
M`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E___OR.PF`"$`?A@2ISA``%@@\+C`
M*P``\`#L(P`(@':E#Z``["``$V!VN00`*J<Y``+`Y?__\"X0$J<:__^($``?
MI_0`!*<8``#5!_$PL"BY%``AIW0`!NNO\8@`!`?^P.7__^]GZV_P,``DX_#^
MP/]QLD\`D.N9`"``#;)/`)'2!_$XD"CL*``)`'RY!`!BE0`@`*=T``O5!_$X
MD"BG=`"6ZV_Q<``$!_[`Y?__\#*Y!`"B["C_\@!\N00`*L#E___NF.PH`&8`
M?$&P(!.5+B`3IW0`!I4`L`&GA/_PE2X@$Z>$`&.G"```N00`.[D$`":G&0``
MITD``+)>`!*G%/_^LEX`0Z<4__ZY"0`6N0D`2QH4IQH``KD4`(&Y!``HP.7_
M_^TWX[#PH``DN00`<J<Y``*Y!`!(P%````[5P.7__^^XN00`)T$P\*C`Y?__
M[?'L*``-_WY8`/#`IUA``,`+``#P`.P%`"N`=KD$`"?`Y?__[Q^Y!``GP.7_
M_^]:N00`*L#E___N->PF_Z``?+D$`"K`Y?__[.VY!``FP.7__^THI_3_>I4N
ML`&G=/^=E0"P`J>$_X.G]/^7N00`)\#E____4Z?T_]C`Y?__[K('!P<'!P?K
M;_`P`"3`$```//WC\/]8_W'CL!````3`4```+JS$2```//7`,```#G>R3P"@
MZZH`(``-LD\`H>,KH```!,!@```/RL#E___O6KD$`%;E2/"@``#`0```"OKC
M*Z````3`,```#F?`Y?__[;GK;_#8``0'_@<'!P>R3P`@P!```#S"ZS(`(``-
MXT`0```$LD\`,<!0```N;^,D,```!,1(```\M<`P```.-\#T___O)^MO\#``
M)./P\`#_<>,`__@`(./P\`#_<>,`__@`(./P_TC_<>,`\+``(.,0\+`"<;)/
M`*#KJ@`@``VR3P"AX[#PKP%QT@<0`*`HP.7__^WOP`````XHXP#PH``DN00`
M8J=)$`&G.0`"N00`*\!0```.%,#E___NV[D$`"M!,/"NITD0`,#E___L\NPD
M`#``?KD$`&*G*@`!N10`@KD$`"C`Y?__[#2Y!`"R["@`$@!\N10`9D$P\*ZY
M!`!8N00`1L#E___LI$$VL`"2`#``XT#PL`)QU0=``*`HIW0`#+D$`"OK;_#H
M`@0'_J>Y``"G]/_PP.7__^W;P/3___^$!P?K;_`P`"3C\/``_W'C`/_X`"#C
M\/ZP_W'C`/%(`"#C$/%(`7&Y!`"BN00`D[)/`(!!,/"TZX@`(``-P"````VV
MLD\`@=('$`"`*,#E___\5Z<Y`"^Y!`"RN00`*L#E___MMNPH`!D`?,`@```-
MI+D$`#K`Y?___*NY!``JXQ#Q2`%QU0<0`(`HIW0`Y^MO\8`!!`?^N00`*<#E
M___LN,`P```-D,#E___L`NPH_]\`?)4`(`"GA`!Y[+@`#P!\IP@``+D$`$*Y
M!``[LET`0Z<4__ZGA`!;IP@``*=9``"Y!`!BLEX`5J<4__ZYZ2`UXY!?__]Q
M["D`-Z!EN>D@":<!``&GA``.E2^0`*=T`""2`)``XY"?__]Q["D`&8!DZ^``
M`0`,E2^0`*=T`!&2`)``ZR^?__]5IW0`"NL`G___4N.0G_[_<:?G_^^G"```
MISD``+D$`!*R7@`QIQ3__KD)`#*G"```IUD``+D$`$JR7@!4IQ3__J<)#_^Y
M"0!:064P`NQ@`";`9<`P```-&Z<I``#`Y?__ZXOL*/]H`'R5`"``IW3_B^RX
M``<`?)4NL`"GA``)ISD``<`@```,]J?T_]*5`+`!IX3_X:?T__7`X```#/GC
MH/"H`"3CX/"@`"2Y!`!BISD``D$@\4C`4```#6&G21``P.7__^V903#PN$$@
M\4C`Y?__Z]+L)O^_`'Y8D/#0I2^``,";``#P`.R2_[5@=D$@\4BG.0`!P.7_
M_^UN[";_JP!^03#Q2,`@```,NL#E___[PT$@\4C`Y?__Z]ZG]/\5P.7__^RI
M!P<'!^N_\%@`)*<Y`"^Y!`"RX_#_8/]QP.7__^TZ01`@`;D"`"*Y!``KN>)P
M(>N_\/@`!,#T___KO`<'ZY_P2``DX_#P`/]QXP#_^``@X_#_6/]QXP#PH``@
MLD\`H.,0\*`!<>NJ`"``#;)/`*'2!Q``H"CL*`!D`'R5`"``IX0`7Z<(``"G
MF0``N00`,K)>`).G%/_^IPD0`+D)`)+L20`!`-GL0`!O(&6Y!``R0;#PH+D$
M`"O`Y?__[6OC6;___W'L6P`?P&6YZ;`EIU$``:=T`$?K0@`!``R5+U``IW0`
M$9(`4`#K+U___U6G=``*ZP!?__]2XU!?_O]QIT?_[[D$`"NG.0`OP.7__^S"
M["@`%P!\["L`,R!EN00`*\#E___K1^/@\*`!<=4'X`"@**=T`"WKG_#P`00'
M_N,0\*`!<=4'$`"@**=T`"'`(```"_[KG_#P`03`]/__ZRJ5+U``IW3_SY(`
M4`#C4%___W'L6_^R8&2G]/_%D@`@`*?T_\ZG*0``I_3_S\#E___KX0<'!P?K
MK_!0`"3C\/]0_W&R3P"@ZZH`(``-LD\`H4&P\*32!_"HH"BY!``[P"````O5
MP.7___IM["@`+@!\XT#PI``4Q"@``#G\ZQ0``P`-XQ`@```(XU`0"``$XU`0
M```D[%C_XP!\XP`0$``$XP`0"``D01`0".P&__@`?+D$`#O`(```"ZK`Y?__
M^D+L)O_8`'RY!``[P"````NDP.7___HW["@`+@!\XQ#PI``4Q%@``#G&Z^$`
M`P`-X^!0```(XP#@"``$XP#@```D[`C_XP!\XS#@$``$XS#@"``D0>#@".PV
M__@`?+D$`#O`(```"WG`Y?__^@SL)O_8`'RY!``[P"````MRP.7___H!["@`
M+@!\XU#PI``4Q.@``#F0ZT4``P`-XT#@```(XS!`"``$XS!````D[#C_XP!\
MXR!`$``$XR!`"``D04!`".PF__@`?+D$`#O`(```"T?`Y?__^=;L)O_8`'RY
M!``[P"````M!P.7___G+["@`+@!\XS#PI``4Q"@``#E:ZQ,``P`-XQ`@```(
MXT`0"``$XT`0```D[$C_XP!\XP`0$``$XP`0"``D01`0".P&__@`?+D$`#O`
M(```"Q;`Y?__^:#L)O_8`'RY!``[P"````L/P.7___F5["@`+@!\XQ#PI``4
MQ$@``#DDZU$``P`-XU!````(XP!0"``$XP!0```D[`C_XP!\X^!0$``$X^!0
M"``D05!0".SF__@`?+D$`#O`(```"N3`Y?__^6KL)O_8`'RY!``[P"````KA
MP.7___E?["@`+@!\XT#PI``4Q%@``#CNZS0``P`-XS!0```(X^`P"``$X^`P
M```D[.C_XP!\XR`P$``$XR`P"``D03`P".PF__@`?+D$`#O`(```"K;`Y?__
M^33L)O_8`'RY!``[P"````J#P.7___DI["@`+@!\X^#PI``4Q"@``#BXZQX`
M`P`-XQ`@```(XS`0"``$XS`0```D[#C_XP!\XP`0$``$XP`0"``D01`0".P&
M__@`?+D$`#O`(```"EC`Y?__^/[L)O_8`'RY!``[P"````I[P.7___CS["@`
M+@!\XQ#PI``4Q#@``#B"ZT$``P`-XT`P```(XP!`"``$XP!````D[`C_XP!\
MXU!`$``$XU!`"``D04!`".Q6__@`?+D$`#O`(```"E#`Y?__^,CL)O_8`'RY
M!``[P"````I*P.7___B]["@`+@!\XS#PI``4Q$@``#A,Z^,``P`-X^!````(
MXU#@"``$XU#@```D[%C_XP!\XR#@$``$XR#@"``D0>#@".PF__@`?+D$`#O`
M(```"A_`Y?__^)+L)O_8`'RY!``[P"````H9P.7___B'["@`+@!\XU#PI``4
MQ.@``#@6ZQ4``P`-XQ#@```(XR`0"``$XR`0```D["C_XP!\XP`0$``$XP`0
M"``D01`0".P&__@`?+D$`#O`(```">[`Y?__^%SL)O_8`'RY!``[P"````FP
MP.7___A1["@`+@!\XQ#PI``4Q"@``#?@ZS$``P`-XS`@```(XP`P"``$XP`P
M```D[`C_XP!\XT`P$``$XT`P"``D03`P".Q&__@`?+D$`#O`(```"87`Y?__
M^";L)O_8`'RY!``[P"````FRP.7___@;["@`"P!\N00`,L`@```)G<#E___X
M>+D$`#O`(```":C`Y?__^`CL*``+`'RY!``RP"````FFP.7___AEN00`.\`@
M```)I,#E___W]>PH`!P`?+D$`#+`(```"43`Y?__^%+5!_"HH"BG=``CP#``
M``F?P"````E6ZZ_Q```$P/3___A!N00`.\`@```)B,#E___WT>PH_^<`?+D$
M`#+`(```"4[`Y?__^"ZG]/_<P.7__^D9!P<'!^N_\%@`),`@```)/N/P_U#_
M<;)/`+!!,/"DZ[L`(``-LD\`L=('\*BP*,#E___WI^PH`"$`?$,0(``8(<`G
M````,+F$``*Y`P`PIQ$`_^M3`#\`#*=(``"Y\H!4U0?PJ+`HN10`):=T``KK
MO_$(``0'_J=8``"G]/_SP.7__^C78`#P@&`@\(A@0/"08&#PF.L_\!@`),08
M```W,>/P_SC_<;D$`$)!`/%HLD\`($%0\,CK,@`@``VR3P`QXR`0```$T@?P
MP#`HXU#PN``DXP#PL``DY4CPH``!Y4CPJ```05#PH*<Y``+`Y?__Z'"G*0#_
MP.7__^@KZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@N2$`_J<D__BY!`#^X_#_
M4/]QXP#PJ``@XQ#PJ!!QISD``+)/`*"Y!`""ZZH`(``-ITD``K)/`*%!L/"@
MT@<0`*`HP.7__^:[[)+__P#9["DP@`!5[`+__P#9N0(`(KGBL`+`,?__``"Y
M@0`#N0(`(KGBL`*G"P`!N0(`(KGBL`*Y"0"0[)0`B@!\N00`.;D$`"BG20``
MP.7__^:1["@`F/]\N00`.[D$`"C`00`!``C`Y?__Z)3L*`"%_WZY%`!"[$P`
M8P=]XQ2_^/]Q[!L`74!E[%$^OP!5Q.@``#:8X^`0```@IX0`:.,0'___<>P;
M`$Q`9>Q8`"0`?.Q8`!8!?.Q8``L"?./@$```(*>$`%3C$!___W'CX!```""G
MA`!,XQ`?__]QX^`0```@IX0`1.,0'___<>P;`"A`9>/@$```(*>$`#GC(!__
M_W&Y!``2X^`@```@IX0`+^,0+___<>/@$```(*>$`"?C$"_^_W'CX"_^_R"G
MA``?XQ`O_?]Q[!O_WJ!EPI0``0``P`'__P``[)#_?&!DIRG__^.`\*@0<=4'
M@`"@**=T`!CKC_#P$`0'_KGIL"&Y"``II_3_\,`@```(&<#E___^U<`@```(
M#,#E___^S\#E___GH`<'Z^_P<``DX_#_8/]QP.7__^6&P.7__^5C["@`!@!\
MXR`@```$Z^_Q$``$!_X'!P<'ZV_P,``DX_#_0/]QN00`HK)/`+!!,/"TZ[L`
M(``-P"````?HLD\`L=('\+BP*,#E___V%>PH``D`?+D$`&*5`"``IW0`$M4'
M\+BP**=T`%&Y!``ZP"````?-ZV_P\``$P/3___9DIP@``+D$`#:Y!``:IRD`
M`*=)``"R7@`AIQ3__K)>`$.G%/_^N0D`*KD)`$9!DD`"N00`*<#E___E9^-@
M\*@`),`````'/.,`\*``)+D$`(*Y!`!JN00`2<!0```'J*<Y``+`Y?__Y^#5
M!_"XL"BG=``-N00`.,`@```'B>MO\/``!,#T___V(,#E___G#0<'!P?K;_`P
M`"2R3P`0X_#^*/]QZS$`(``-LD\`,>,P\,@`)-('\=`P*,!````U;4&`\-2Y
M!``XTD?P^$`0XR#PP``DP"````;GT@_PX$!8T@?P\$!HP.7___6'["@`"0!\
MN00`LI4`(`"G=`*6P.7__^3#P.7__^2@["@!.0!\XZ`@```"IX0!,Z<(``"G
M*0``N00`6K)>`"6G%/_^N0D`*NNR``$`#:>[``&Y!``KP.7__^3BXP"@``"4
MN00`DI4`H`"GA`)\N00`>[D$`-*Y!`!+N00`*;D6`&"G.0`"P%````<90:"@
M`<#E___G5;DA`'NY!``[N>(@-^,`H```E+GIL$.G2P`"N2$`0[GBT$.YZ3`K
M09"0`N.R3_[_<94`H`"G=/_606#Q&,`@```&PJ?T``FG:P`(XR!O^/\"IX0`
M(+D$`#C`Y?__]0ZY!`!R["C_\@!\E0`@`*>$_^W`Y?__]J[L*/_H`'ZY!``G
MP.7__^6"N00`8NPF`!T`?$&0\/CC8)````*GA``5E0!@`*>$`*FY!``FP.7_
M__:1["8`E`!^IYL`".-@D````J=T_^^G"```N00`[:=9``"Y!`"VIZD``+)>
M`%NG%/_^LEX`KJ<4__ZY"0!6N0D`K1I:IUH$!+D4`*6Y!``JP.7__^1#P```
M``8<X]#PL``DXP#PH``DN00`DJ<Y``*Y!`!*P-````:(X]#PJ``DP%````9]
MP.7__^:XN00`*:<Y`<#`Y?__Y:'L)@`+_W[`Y?__Y6M8$"``[!8!BA%^0=#Q
M0+D$`"FY!``]P.7__^8-&++L)@`-`'Y8,/%8ITA``,`[``#P`.PT`(2`=KD$
M`&GC@/#```3$F```-"_C4(````3`0```!FGC()````2G.0`"P.7__^79IWD`
M`.-@\,@`!-4'\=!@**=T`ARY!``GZV_R"``$!_ZY!``FP.7__^34N00`8NPF
M_V\`?*>;``BG]/]EIVD``*?T_V9!8/#@XR!@```"IX0`%;D$`#C`Y?__]#/L
M*``'`'R5`"``IW0`':=K``CC(&````*G=/_OIRD`#:=Y``VGN0`-P.7__^.D
MP*````7LN00`DKD$`-*G"`!3I_3^QL#E___DEKD$`*+L*/_@`'RG"```I^D`
M`+D$`!*R7@#AIQ3__KD)`.+KO@`!``VGNP`!I_3^F5A@\5S`Y?__XSGL8O]Z
M8'98</%8IR@!P,![```!_^QR_W!@=KD$`"K`Y?__XV>Y!``XN00`<L`@```&
M`L#E___SU>PH`0(`?.-0\,``!+D$`#+C(%````3`Y?__]TNY!`!B["@`\@!\
MIP@``*<9``"Y!``VLEX`$Z<4__ZY"0`6[!P`'@-^N10`0<!0```%V^,D;_S_
M<;)=`%*G%/_^IW0`#^P8`4,$?J<:__NY%`#A01Y@`)4O$`"GA`$XN00`.,`@
M```%&,#E___SD.PH`,4`?.,`(```E)4`(`"GA`"][`@`NS!^P#````4]P"``
M``4"N00`:<#E___SX,#E___DC<!0```&!\`0```$T[D$`-+C4/"P`"2Y!`!*
MN00`)^,0\*``)./0\*@`),!0```%GJ<Y``+`Y?__Y7"G]``SP.7__^0K6$`@
M`.Q&`#81?L#E___D8\`P```$K+D$``*GN@`!P(````76XS#PH``DN10`V[D$
M`&FY!`!*N00`)^.`\+@`).,`\*@`),!0```%=>/0\+``)*<Y``+`Y?__Y3VY
M!``GISD!P,#E___D)NPH_\C_?KD$`"G`Y?__Y.ZY!``WP"````1HP.7___-V
MN00`)\#E___\W:?T_JKC(/#```2Y%``1XU`@```$Q'@``#*\XQ#PH``DN00`
M:<!````$UN,@<```!*<Y``+`Y?__Y&2G]/Z+P.7___R[XT#PR``$U0?QT$`H
MIW0`I+D$`"OK;_((``3`]/__XU^Y!`#2I_3]M./@\,``!.-@X```!*?T_PNY
M!``FISD``,#E___DK+D$`(+L*/\_`'[`Y?__^WRY!`!B["3_-P!\ITD``.,P
M;_;_<;D$`"C`Y?__XE6Y!``H03#PVJ=)``;`Y?__Y%SL)@!J!GS`,```)`?5
M!3``\-JG=/\8XS!OSO]QITD``+D$`"C`Y?__XC>Y!``HN00`/:=)`"C`Y?__
MY#[L)@!,*'S`X```!17`4````^&Y!`!*XU#PH``DN00`:;D$`">2`/%HX^#P
ML``DX]#PJ``DP%````2BISD``L#E___D?*?T_TGC,/#```3C0#`(``*GA/[$
MIP@``*=9``"Y!``DLEX`4J<4__ZY"0!4[%S^M@-]X^5/_/]QP!````1ULET`
M'J<4__ZYXH!DI_3^I\#E___CDL`@```$:L#E___ZN`<'ZW_P.``DX_#_4/]Q
MP*```#'6LD\`L.,0H```!.N[`"``#;)/`+'CD;````1!,/"DT@?PJ+`HT@"0
ML9"PP"````.)P.7___(/["@`!P!\E3$@`*>$`-+`Y?__]X'C(*````3CDK``
M``2Y!``IIUD``Z=)``'`,```!$?`Y?__X=NY!`"2["@`'P!\XS`@$``$XW"@
M```$XS`P```$P$````0TXR>P```$P.7__^'4XT"0$``$XS!````$D4`P#:=T
M`*_C<*````2G60`#XR>P```$ITD``<`P```$&L#E___AJKD$`)+L*``<`'Q!
M,/"DP"````,4P.7___&UXU"0$``$XS!0```$["@`?0!\N00`0N,GL```!,#E
M___AG..@H```!*=)``'C>K````3`,````^^Y!``GP.7__^#LP$````/RN00`
M,KD$`"?`Y?__X8+C&K````22`!"Q03#PI,`@```"U\#E___Q?<0K```QDKD$
M`)+L*``L`'RY!``IISD!P,#E___B=NP"``$`V.P,`!8!?^PH`!,1?KD$`%+$
MN```,72Y!`!)P"````/0XS"P```$P.7__^+]U0?PJ+`HIW0`->M_\.@`!`?^
MQ"@``#%=P.7___N6Q"L``#%;N00`DNPF_\P`?,`@```#G\#E___BX)4`(`&G
MA/\WI_3_+,3H```Q0[D$`"/C,.````3`Y?__\*>G]/^#XR>P```$P.7__^)G
MI_3_3<#E___B<@<'!P<'!^N?\$@`)./P_U#_<;D$`**Y!`"2LD\`L$$P\*3K
MNP`@``W`(````HBR3P"QT@?PJ+`HP.7___#[["@`%`!\XQ`@``"4E0`@`*>$
M``SL&``*,'[LJ``'`'R5`*``IW0`"]4'\*BP**=T`#7KG_#X``0'_KD$`"K`
MY?__]:FG.0`ON00`HL#E___BRKD"`")!`"`!N00`*KGB<"#`Y?__X4^G20`$
MP#````*AP.7__^#7[";_V`!^U0?PJ+`HIW0`"KD$`"GKG_#X``3`]/__\J/`
MY?__X@0'!^OO\'``)*<I`(#C\/]@_W'`Y?__X"C`$6=%(P'`#^_-JXGC$"``
M`"3C`"`(`"3`/YBZW/[`01`R5';C,"`0`"3C0"`8`"3`7\/2X?#E2"`H``#C
M4"`@`"3E2"`P``#E3"!X``#K[_$0``0'_@<'!P?K;_`P`"2Y!`#OX_#_4/]Q
MI^O_\&"`X`!@H.`(N00`LKD$`*3C4"`H``3K%``#``WC0"`P``2Y"``5["0`
M`0#9[`$@OP!5N3$`4;GB($+C`+`H`"3K:@`=``RYZ$!VXW"P,``DN00`8^.`
ML'@`$J=T`)E!<+`X[*P`@C]^Z^H`!@#>[%X@N095I^K__^Q%_\``V4$58`#K
MA``&``RY%@`.IXL``1C>L\$`H;/!`("Y!`"6["@^OP!5IX0`*^PH`!H!?.PH
M``T"?-(_<`!@`+D$`"M!D&!`P.7__^11TC]P`)``N00`*T&0D$#`Y?__Y$?2
M/W``D`"Y!``K09"00,#E___D/;/-`#KLDP`J@&3KB``"``S2/W``D`"Y!``K
MP.7__^0MTC]P`)!`N00`*\#E___D)=(_<`"0@+D$`"O`Y?__Y!W2/W``D,"Y
M!``K09"1`,#E___D$Z>'_]ZSS0!8Z^T`!@#?IZK_P.O5``8`#1NN06U@0+D4
M`*JY!``VN00`)[D$`$K`Y?__XB50H+!X:(#PH&B@\*CK;_#@``0'_J>8`$`;
MF!F:07"P.+GRL)JY!``GN1@`*+D4`$G`Y?__X@H8.5HPL'A0,+!X[#;_XD!^
M&ZFY&`!IN00`*[D4`*K`Y?__X\RG]/](!P<'!P<'ZX_P0``DN00`L^.`,"@`
M!..0,#``!.P8.K\]5>/P_V#_<;D4`#%!0[`XDH!``+D$`**G&@`!N10`(4$R
ML#CL'`!).'ZG2`!`N?D0).Q!``J`=J<J__^Y%@`2QA````!+N00`*\#E___C
MDM<WL#BP.*<Y``#L.0`'8%7L.0@/8%7L.1`78%7L.1@?(%6Y!``K[(,`'P!5
MXX"P<``DP.7__^-VT@.@`+`$N00`*](#H`2P#-(#H`BP%-(#H`RP'-(#H!"P
M).N/\.``!,#T___@ZZ<(`#BY^1!0[`'_S(!VIUK__[D6`.7&X`````BG]/_"
MUP`P`#``UP`P`#``!P<'!\18```NQ,#T___>C0<'!P?K;_`P`"3C$/!X``2G
M^_]@XQ#P```DP,```"V9XT#Q$``$ZV_PT``$!_0``````````@`!+W!R;V,O
M<V5L9B]E>&4``"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%
M35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU
M3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'``!0
M05)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@``,0!L<V5E:R!F86EL960``')E860@9F%I;&5D
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``"5S)7,E<R5S``!P87(M
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(``!P87)L```N<&%R``!S:&]R="!R96%D```E<R5S
M8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```8
M`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#8T`%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E
M=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P
M86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@
M/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F
M:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S
M:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@
M;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS
M965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B
M=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*
M)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G
M;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA
M;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R
M<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#
M86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M
M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T
M<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T
M<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N
M(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F
M+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER
M<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D
M9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C
M)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U
M;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O
M+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?
M34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T
M:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+
M6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E
M860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D
M97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S
M?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@
M("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE
M+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F
M8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME
M>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>
M+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*
M;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN
M=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD
M=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2![
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B
M)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H
M(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@
M,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H
M95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%
M(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I
M.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@
M;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q
M<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X
M=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D
M9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D
M8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@
M/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O
M7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D
M9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N
M86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%2
M7R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%4@``55-%4DY!
M344``%1%35!$25(`5$U0`"]T;7``````<&5R;'AS:2YC``!#04-(10``````
M`````1L#.P```.P````<__^",```!B3__X2P```!"/__A;@```$X__^<(```
M`7C__YT@```!N/__G?````((__^@>````DC__Z$(```">/__HG@```*T__^B
M\````O#__Z,H```#!/__I"````-(__^D*````US__Z:(```#G/__IL````/(
M__^H&```!!#__ZVH```$1/__KB@```1T__^NH```!*#__["8```$Y/__L,@`
M``4$__^QP```!53__[C````%I/__NO@```7@__^[T```!F3__[Q````&B/__
MOC````;,__^_,```!P@`````````%``````!>E(``7@.`1L,#Z`!!PX`````
M%````!S__X.@````0@``````````````%``````!>E(``7@.`1L,#Z`!````
M````/````!S__X1X```68@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q9"
M"L_.S<S+RLG(Q\8.H`%""P```````#P```!<__^:H````/H`1H<-B`R)"XH*
MBPF,"(T'C@:/!48.H"%,#L@B`I0*S\[-S,O*R<C'#J`!0@L```````!,````
MG/__FV````#.`$R&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("C`K/SLW,R\K)
MR,?&#J`!0@M<"L_.S<S+RLG(Q\8.H`%""P```````#P```#L__^;X````H(`
M1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`@,!5@K/SLW,R\K)R,?&#J`!0@L`
M```````L```!+/__GB@```"0`$:*"HL)C`B-!XX&CP5&#M@#`GP*S\[-S,O*
M#J`!0@L````X```!7/__GH@```%J`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MX`-V"L_.S<S+RLG(Q\8.H`%""P`````X```!F/__G[P```!T`$R&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.R`("8,_.S<S+RLG(Q\8.H`$````````0```!U/__
MG_@````X`````````$````'H__^@'````/@`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@Z@(4P.H$%,#MA"`L0*S\[-S,O*R<C'Q@Z@`4(+````$````BS__Z#0
M````!@`````````\```"0/__H,0```)<`$:&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.H"%,#O`C`GH*S\[-S,O*R<C'Q@Z@`4(+````*````H#__Z+D````-@!*
MBPF,"(T'C@:/!4H.P`)<S\[-S,L.H`$```````!$```"K/__HO````%4`$:)
M"XH*BPF,"(T'C@:/!48.H"%,#L@B`N8*S\[-S,O*R0Z@`4(+7`K/SLW,R\K)
M#J`!1@L````````P```"]/__I`````6,`$:*"HL)C`B-!XX&CP5&#M`"`P5*
M"L_.S<S+R@Z@`48+````````+````RC__ZE<````@`!,BPF,"(T'C@:/!48.
MT`("7@K/SLW,RPZ@`4(+````````*````UC__ZFL````>`!<A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5&#N@"``````!````#A/__J?@```'V`$:(#(D+B@J+"8P(
MC0>.!H\%1@P.H($$6`T/1@[0@@0#`:`*S\[-S,O*R<@.H`%""P```````!P`
M``/(__^KK````"P`1HX&CP5&#L`"7L_.#J`!````3````^C__ZN\````]`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`E0*S\[-S,O*R<C'Q@Z@`48+`H(*
MS\[-S,O*R<C'Q@Z@`48+``````!,```$./__K&0```;^`$J&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.^`0#`K(*S\[-S,O*R<C'Q@Z@`4(+`P+N"L_.S<S+RLG(
MQ\8.H`%&"P```#@```2(__^S%````C(`1H<-B`R)"XH*BPF,"(T'C@:/!48.
MT`(#`<`*S\[-S,O*R<C'#J`!0@L``````$````3$__^U$````-8`1HD+B@J+
M"8P(C0>.!H\%1@[0`@)D"L_.S<S+RLD.H`%""P)8"L_.S<S+RLD.H`%&"P``
M````/```!0C__WP$```"@`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'`
M"L_.S<S+RLG(Q\8.H`%""P```````"````5(__^U9````&P`2HX&CP5&#L`"
M`EK/S@Z@`0```````$````5L__^UL````>H`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%2@[0`DR8%ID5`P&""L_.S<S+RLG(Q\;9V`Z@`4(+````.```!;#__[=<
M````_`!&B`R)"XH*BPF,"(T'C@:/!5P.P`("J`K/SLW,R\K)R`Z@`48+````
M````````$```!>S__[@@````#```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````*0`````````HN```````
M```!`````````MH``````````0````````+E`````````!T````````$80``
M```````,````````'F``````````#0```````&*0`````````!D```````"[
MJ``````````;``````````@`````````&@```````+NP`````````!P`````
M````"``````````$`````````I``````;__^]0````````>@``````````4`
M```````1.``````````&````````"(``````````"@````````25````````
M``L`````````&``````````5`````````````````````P```````+W8````
M``````(````````%$``````````4``````````<`````````%P```````!E0
M``````````<````````6^``````````(`````````E@`````````"0``````
M```8`````````!X`````````"`````!O___[``````@```$`````;____@``
M`````!:(`````&____\``````````0````!O___P````````%<X`````;___
M^0`````````.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[N``````````````````````````````>S@```````![N````````
M'PX````````?+@```````!].````````'VX````````?C@```````!^N````
M````'\X````````?[@```````"`.````````("X````````@3@```````"!N
M````````((X````````@K@```````"#.````````(.X````````A#@``````
M`"$N````````(4X````````A;@```````"&.````````(:X````````AS@``
M`````"'N````````(@X````````B+@```````").````````(FX````````B
MC@```````"*N````````(LX````````B[@```````",.````````(RX`````
M```C3@```````"-N````````(XX````````CK@```````"/.````````(^X`
M```````D#@```````"0N````````)$X````````D;@```````"2.````````
M)*X````````DS@```````"3N````````)0X````````E+@```````"5.````
M````)6X`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````)8```````````````````,`("E!!4BYP;0H`````````````
M`````*,P````````8QP``````````````````&.\````````8\````````"C
M)````````&,B````````HRP``````````````````*,4````````HQH`````
M`````````````&6D1T-#.B`H4U5312!,:6YU>"D@,34N,2XQ(#(P,C4P-C(V
M```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB
M=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO
M;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"`````````````````````$```````````````A````!P`````````"````
M`````F@````````":``````````D````````````````````!```````````
M````.`````4``````````@````````*0`````````I`````````%$`````8`
M``````````````@`````````"````#1O___V``````````(````````'H```
M``````>@`````````-P````&```````````````(```````````````^````
M"P`````````"````````"(`````````(@`````````BX````!P````(`````
M````"``````````8````1@````,``````````@```````!$X````````$3@`
M```````$E0````````````````````$``````````````$YO____````````
M``(````````5S@```````!7.`````````+H````&```````````````"````
M``````(```!;;____@`````````"````````%H@````````6B`````````!P
M````!P````$`````````"```````````````:@````0``````````@``````
M`!;X````````%O@````````"6`````8```````````````@`````````&```
M`'0````$`````````$(````````94````````!E0````````!1`````&````
M%@`````````(`````````!@```!^`````0`````````&````````'F``````
M```>8``````````^````````````````````!```````````````>0````$`
M````````!@```````!Z@````````'J`````````&X```````````````````
M``0`````````(````(0````!``````````8````````E@````````"6`````
M````/1`````````````````````(``````````````"*`````0`````````&
M````````8I````````!BD``````````J````````````````````!```````
M````````D`````$``````````@```````&+`````````8L````````!`D```
M``````````````````@``````````````)@````!``````````(```````"C
M4````````*-0`````````.P````````````````````$``````````````"F
M`````0`````````"````````I$````````"D0`````````8P````````````
M````````"```````````````L`````X``````````P```````+NH````````
MJZ@`````````"`````````````````````@`````````"````+P````/````
M``````,```````"[L````````*NP``````````@````````````````````(
M``````````@```#(````!@`````````#````````N[@```````"KN```````
M``(@````!P``````````````"``````````0````T0````$``````````P``
M`````+W8````````K=@````````"*`````````````````````@`````````
M"````-8````!``````````,```````#``````````+```````````(@`````
M```````````````(``````````````#<````"``````````#````````P(@`
M``````"PB``````````H````````````````````"```````````````X0``
M``$`````````,```````````````````L(@`````````(@``````````````
M``````$``````````0````$````#`````````````````````````````+"J
@`````````.H````````````````````!````````````
